@@ -21,9 +21,11 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 from __future__ import print_function
 
+from distutils.version import LooseVersion
 import logging # pylint: disable=unused-import
 import posixpath
 
+import hpccm.templates.envvars
 import hpccm.templates.ldconfig
 import hpccm.templates.rm
 import hpccm.templates.sed
@@ -37,20 +39,21 @@ from hpccm.primitives.copy import copy
 from hpccm.primitives.environment import environment
 from hpccm.primitives.shell import shell
 
-class charm(bb_base, hpccm.templates.ldconfig, hpccm.templates.rm,
-            hpccm.templates.sed, hpccm.templates.tar, hpccm.templates.wget):
+class charm(bb_base, hpccm.templates.envvars, hpccm.templates.ldconfig,
+            hpccm.templates.rm, hpccm.templates.sed, hpccm.templates.tar,
+            hpccm.templates.wget):
     """The `charm` building block downloads and install the
     [Charm++](http://charm.cs.illinois.edu/research/charm) component.
 
-    As a side effect, this building block modifies `PATH` to include
-    the Charm++ build.  It also sets the `CHARMBASE` environment
-    variable to the top level install directory.
-
     # Parameters
 
     check: Boolean flag to specify whether the test cases should be
     run.  The default is False.
 
+    environment: Boolean flag to specify whether the environment
+    (`LD_LIBRARY_PATH`, `PATH`, and other variables) should be
+    modified to include Charm++. The default is True.
+
     ldconfig: Boolean flag to specify whether the Charm++ library
     directory should be added dynamic linker cache.  If False, then
     `LD_LIBRARY_PATH` is modified to include the Charm++ library
@@ -60,7 +63,8 @@ class charm(bb_base, hpccm.templates.ldconfig, hpccm.templates.rm,
     The default values are `--build-shared`, and `--with-production`.
 
     ospackages: List of OS packages to install prior to configuring
-    and building.  The default values are `git`, `make`, and `wget`.
+    and building.  The default values are `autoconf`, `automake`,
+    `git`, `libtool`, `make`, and `wget`.
 
     prefix: The top level install prefix.  The default value is
     `/usr/local`.
@@ -72,7 +76,7 @@ class charm(bb_base, hpccm.templates.ldconfig, hpccm.templates.rm,
     The default value is `multicore-linux-x86_64`.
 
     version: The version of Charm++ to download.  The default value is
-    `6.8.2`.
+    `6.9.0`.
 
     # Examples
 
@@ -96,23 +100,27 @@ class charm(bb_base, hpccm.templates.ldconfig, hpccm.templates.rm,
         self.__check = kwargs.get('check', False)
         self.__options = kwargs.get('options', ['--build-shared',
                                                 '--with-production'])
-        self.__ospackages = kwargs.get('ospackages', ['git', 'make', 'wget'])
+        self.__ospackages = kwargs.get('ospackages',
+                                       ['autoconf', 'automake', 'git',
+                                        'libtool', 'make', 'wget'])
         self.__parallel = kwargs.get('parallel', 4)
         self.__prefix = kwargs.get('prefix', '/usr/local')
         self.__target = kwargs.get('target', 'charm++')
         self.__target_architecture = kwargs.get('target_architecture',
                                                 'multicore-linux-x86_64')
-        self.__version = kwargs.get('version', '6.8.2')
+        self.__version = kwargs.get('version', '6.9.0')
+
+        # Version 6.9.0 dropped the 'v' from directory name
+        if LooseVersion(self.__version) >= LooseVersion('6.9.0'):
+            self.__installdir = posixpath.join(
+                self.__prefix, 'charm-{}'.format(self.__version))
+        else:
+            self.__installdir = posixpath.join(
+                self.__prefix, 'charm-v{}'.format(self.__version))
 
-        self.__installdir = posixpath.join(self.__prefix,
-                                           'charm-v{}'.format(self.__version))
         self.__wd = '/var/tmp' # working directory
 
         self.__commands = [] # Filled in by __setup()
-        self.__environment_variables = {
-            'CHARMBASE': self.__installdir,
-            'PATH': '{}:$PATH'.format(posixpath.join(self.__installdir,
-                                                     'bin'))}
 
         # Construct series of steps to execute
         self.__setup()
@@ -126,8 +134,7 @@ class charm(bb_base, hpccm.templates.ldconfig, hpccm.templates.rm,
         self += comment('Charm++ version {}'.format(self.__version))
         self += packages(ospackages=self.__ospackages)
         self += shell(commands=self.__commands)
-        if self.__environment_variables:
-            self += environment(variables=self.__environment_variables)
+        self += environment(variables=self.environment_step())
 
     def __setup(self):
         """Construct the series of shell commands, i.e., fill in
@@ -168,7 +175,7 @@ class charm(bb_base, hpccm.templates.ldconfig, hpccm.templates.rm,
         if self.ldconfig:
             self.__commands.append(self.ldcache_step(directory=libpath))
         else:
-            self.__environment_variables['LD_LIBRARY_PATH'] = '{}:$LD_LIBRARY_PATH'.format(libpath)
+            self.environment_variables['LD_LIBRARY_PATH'] = '{}:$LD_LIBRARY_PATH'.format(libpath)
 
         # Check the build
         if self.__check:
@@ -179,6 +186,11 @@ class charm(bb_base, hpccm.templates.ldconfig, hpccm.templates.rm,
         self.__commands.append(self.cleanup_step(
             items=[posixpath.join(self.__wd, tarball)]))
 
+        # Set the environment
+        self.environment_variables['CHARMBASE'] = self.__installdir
+        self.environment_variables['PATH'] = '{}:$PATH'.format(
+            posixpath.join(self.__installdir, 'bin'))
+
     def runtime(self, _from='0'):
         """Generate the set of instructions to install the runtime specific
         components from a build in a previous stage.
@@ -199,7 +211,5 @@ class charm(bb_base, hpccm.templates.ldconfig, hpccm.templates.rm,
             instructions.append(shell(
                 commands=[self.ldcache_step(
                     directory=posixpath.join(self.__prefix, 'lib_so'))]))
-        if self.__environment_variables:
-            instructions.append(environment(
-                variables=self.__environment_variables))
+        instructions.append(environment(variables=self.environment_step()))
         return '\n'.join(str(x) for x in instructions)
