@@ -26,6 +26,7 @@ import posixpath
 import re
 
 import hpccm.config
+import hpccm.templates.envvars
 import hpccm.templates.rm
 import hpccm.templates.sed
 import hpccm.templates.tar
@@ -40,17 +41,14 @@ from hpccm.primitives.environment import environment
 from hpccm.primitives.shell import shell
 from hpccm.toolchain import toolchain
 
-class intel_psxe(bb_base, hpccm.templates.rm, hpccm.templates.sed,
-                 hpccm.templates.tar):
+class intel_psxe(bb_base, hpccm.templates.envvars, hpccm.templates.rm,
+                 hpccm.templates.sed, hpccm.templates.tar):
     """The `intel_psxe` building block installs [Intel Parallel Studio
     XE](https://software.intel.com/en-us/parallel-studio-xe).
 
     You must agree to the [Intel End User License Agreement](https://software.intel.com/en-us/articles/end-user-license-agreement)
     to use this building block.
 
-    As a side effect, this building block modifies `PATH` and
-    `LD_LIBRARY_PATH`.
-
     # Parameters
 
     components: List of Intel Parallel Studio XE components to
@@ -67,6 +65,11 @@ class intel_psxe(bb_base, hpccm.templates.rm, hpccm.templates.sed,
     flag does not control whether the developer environment is
     installed; see `components`.  The default is True.
 
+    environment: Boolean flag to specify whether the environment
+    (`LD_LIBRARY_PATH`, `PATH`, and others) should be modified to
+    include Intel Parallel Studio XE. `psxevars` has precedence. The
+    default is True.
+
     eula: By setting this value to `True`, you agree to the [Intel End User License Agreement](https://software.intel.com/en-us/articles/end-user-license-agreement).
     The default value is `False`.
 
@@ -190,7 +193,7 @@ class intel_psxe(bb_base, hpccm.templates.rm, hpccm.templates.sed,
         self.__ospackages = kwargs.get('ospackages', [])
         self.__prefix = kwargs.get('prefix', '/opt/intel')
         self.__psxevars = kwargs.get('psxevars', True)
-        self.__runtime_version = kwargs.get('runtime_version', '2019.1-144')
+        self.__runtime_version = kwargs.get('runtime_version', '2019.4-243')
         self.__tarball = kwargs.get('tarball', None)
         self.__tbb = kwargs.get('tbb', True)
         self.__wd = '/var/tmp' # working directory
@@ -229,7 +232,7 @@ class intel_psxe(bb_base, hpccm.templates.rm, hpccm.templates.sed,
             # subsequent build steps.
             self += shell(commands=['echo "source {0}/compilers_and_libraries/linux/bin/compilervars.sh intel64" >> {1}'.format(self.__prefix, self.__bashrc)])
         else:
-            self += environment(variables=self.__environment())
+            self += environment(variables=self.environment_step())
 
     def __distro(self):
         """Based on the Linux distribution, set values accordingly.  A user
@@ -380,6 +383,9 @@ class intel_psxe(bb_base, hpccm.templates.rm, hpccm.templates.sed,
             items=[posixpath.join(self.__wd, self.__tarball_name),
                    posixpath.join(self.__wd, basedir)]))
 
+        # Set the environment
+        self.environment_variables = self.__environment()
+
     def runtime(self, _from='0'):
         """Install the runtime from a full build in a previous stage"""
         return str(intel_psxe_runtime(daal=self.__daal,
